HashmapDatabase

Struct HashmapDatabase 

pub struct HashmapDatabase<K: Eq + Hash, V> { /* private fields */ }
The HMapDatabase mimics the behaviour of LMDBDatabase without keeping a persistent copy of the key-value records. It allows key-value pairs to be inserted, retrieved and removed in a thread-safe manner.

Implementations

Source

impl<K: Clone + Eq + Hash, V: Clone> HashmapDatabase<K, V>

pub fn new() -> Self

Creates a new empty HMapDatabase with the specified name

pub fn insert(&self, key: K, value: V) -> Result<(), KeyValStoreError>

Inserts a key-value record into the database. Internally, insert serializes the key and value using bincode and adds the pair into HashMap guarded with a RwLock.

pub fn get(&self, key: &K) -> Result<Option<V>, KeyValStoreError>

Get a value from the key-value database. The retrieved value is deserialized from bincode into V

pub fn is_empty(&self) -> Result<bool, KeyValStoreError>

Returns if the key-value database is empty

pub fn len(&self) -> Result<usize, KeyValStoreError>

Returns the total number of entries recorded in the key-value database.

pub fn for_each<F>(&self, f: F) -> Result<(), KeyValStoreError>

Iterate over all the stored records and execute the function f for each pair in the key-value database.

pub fn contains_key(&self, key: &K) -> Result<bool, KeyValStoreError>

Checks whether a record exist in the key-value database that corresponds to the provided key.

pub fn remove(&self, key: &K) -> Result<(), KeyValStoreError>

Remove the record from the key-value database that corresponds with the provided key.